# from sharetop.core.fund.get_fund_rank import fund_open_fund_rank, fund_exchange_rank, fund_money_rank, fund_hk_rank

import pandas as pd


h = [{"a": 1, "b": 2}, {"a": 3, "b": 5}]

df = pd.DataFrame(h)
print(df)